    Info<< "Reading thermophysical properties\n" << endl;
    
	 //region 1 fluid domain
    autoPtr<basicThermo> thermo
    (
        basicThermo::New(mesh1)
    );

    volScalarField& p = thermo->p();
    volScalarField& h = thermo->h();
    const volScalarField& psi = thermo->psi();

    volScalarField rho
    (
        IOobject
        (
            "rho",
            runTime.timeName(),
            mesh1,
            IOobject::NO_READ,
            IOobject::AUTO_WRITE
        ),
        thermo->rho()
    );


    Info<< "\nReading field U\n" << endl;
    volVectorField U
    (
        IOobject
        (
            "U",
            runTime.timeName(),
            mesh1,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh1
    );

#   include "createPhi.H"


    Info<< "Creating turbulence model\n" << endl;
    autoPtr<compressible::turbulenceModel> turbulence
    (
        compressible::turbulenceModel::New
        (
            rho,
            U,
            phi,
            thermo()
        )
    );    
    


    Info<< "Creating field DpDt\n" << endl;
    volScalarField DpDt = 
        fvc::DDt(surfaceScalarField("phiU", phi/fvc::interpolate(rho)), p);


    // Region, solid domain


    Info<< "solid region: Reading field T\n" << endl;

    volScalarField T2
    (
        IOobject
        (
            "T",
            runTime.timeName(),
            mesh2,
            IOobject::MUST_READ,
            IOobject::AUTO_WRITE
        ),
        mesh2
    );


    Info<< "solid region:Reading transportProperties\n" << endl;

    IOdictionary transportProperties2
    (
        IOobject
        (
            "transportProperties",
            runTime.constant(),
            mesh2,
            IOobject::MUST_READ,
            IOobject::NO_WRITE
        )
    );


    Info<< "Reading diffusivity DT\n" << endl;

    dimensionedScalar DT2
    (
        transportProperties2.lookup("DT2")
    );

    Info<< "Reading conductivity K\n" << endl;

    dimensionedScalar K2
    (
        transportProperties2.lookup("K2")
    );
